@@ -570,9 +570,9 @@ def AddConcurrencyFlag(parser):
       type=arg_parsers.CustomFunctionValidator(
           _ConcurrencyValue, 'must be an integer greater than 0 or "default".'),
       help='Set the maximum number of concurrent requests allowed per '
-      'container instance. If concurrency is unspecified, '
-      'any number of concurrent requests are allowed. To unset '
-      'this field, provide the special value `default`.')
+      'container instance. Leave concurrency unspecified or provide the '
+      'special value \'default\' to receive the server default value.'
+  )
 
 
 def AddTimeoutFlag(parser):
