@@ -35,8 +35,6 @@ class Failover(base.Command):
   def Args(parser):
     """Specifies additional command flags.
 
-      --region: The region the cluster will be located in.
-
     Args:
       parser: argparse.Parser: Parser object for command line inputs.
     """
@@ -45,14 +43,14 @@ class Failover(base.Command):
     flags.AddCluster(parser)
 
   def Run(self, args):
-    """This is what gets called when the user runs the command.
+    """Constructs and sends request.
 
     Args:
       args: argparse.Namespace, An object that contains the values for the
           arguments specified in the .Args() method.
 
     Returns:
-      A resource object dispatched by display.Displayer().
+      ProcessHttpResponse of the request made.
     """
     client = api_util.AlloyDBClient(api_util.API_VERSION_DEFAULT)
     alloydb_client = client.alloydb_client
