@@ -50,16 +50,13 @@ def _PrintAndConfirmWarningMessage(args, database_version):
   """Print and confirm warning indicating the effect of applying the patch."""
   continue_msg = None
 
-  # TODO(b/162789572): `in` check is only required until GA.
-  active_directory_changed = ('active_directory_domain' in args and
-                              args.active_directory_domain is not None)
   insights_query_length_changed = (
       'insights_config_query_string_length' in args and
       args.insights_config_query_string_length is not None)
   if any([
       args.tier,
       args.enable_database_replication is not None,
-      active_directory_changed,
+      args.active_directory_domain is not None,
       insights_query_length_changed,
   ]):
     continue_msg = ('WARNING: This patch modifies a value that requires '
@@ -133,6 +130,7 @@ def AddBaseArgs(parser):
   """Adds base args and flags to the parser."""
   # TODO(b/35705305): move common flags to command_lib.sql.flags
   flags.AddActivationPolicy(parser)
+  flags.AddActiveDirectoryDomain(parser)
   flags.AddAssignIp(parser)
   base.ASYNC_FLAG.AddToParser(parser)
   gae_apps_group = parser.add_mutually_exclusive_group()
@@ -210,10 +208,11 @@ def AddBaseArgs(parser):
       '--remove-deny-maintenance-period',
       action='store_true',
       help='Removes the user-specified deny maintenance period.')
-  flags.AddInsightsConfigQueryInsightsEnabled(parser)
+  flags.AddInsightsConfigQueryInsightsEnabled(parser, show_negated_in_help=True)
   flags.AddInsightsConfigQueryStringLength(parser)
-  flags.AddInsightsConfigRecordApplicationTags(parser)
-  flags.AddInsightsConfigRecordClientAddress(parser)
+  flags.AddInsightsConfigRecordApplicationTags(
+      parser, show_negated_in_help=True)
+  flags.AddInsightsConfigRecordClientAddress(parser, show_negated_in_help=True)
   flags.AddMemory(parser)
   parser.add_argument(
       '--pricing-plan',
@@ -241,18 +240,17 @@ def AddBetaArgs(parser):
   labels_util.AddUpdateLabelsFlags(parser, enable_clear=True)
 
 
-def AddAlphaArgs(parser):
+def AddAlphaArgs(unused_parser):
   """Adds alpha args and flags to the parser."""
-  flags.AddActiveDirectoryDomain(parser)
+  pass
 
 
-def RunBasePatchCommand(args, release_track, enable_secondary_zone):
+def RunBasePatchCommand(args, release_track):
   """Updates settings of a Cloud SQL instance using the patch api method.
 
   Args:
     args: argparse.Namespace, The arguments that this command was invoked with.
     release_track: base.ReleaseTrack, the release track that this was run under.
-    enable_secondary_zone: boolean, if enable_secondary_zone is enabled.
 
   Returns:
     A dict object representing the operations resource describing the patch
@@ -268,7 +266,7 @@ def RunBasePatchCommand(args, release_track, enable_secondary_zone):
   sql_messages = client.sql_messages
 
   validate.ValidateInstanceName(args.instance)
-  validate.ValidateInstanceLocation(args, enable_secondary_zone)
+  validate.ValidateInstanceLocation(args)
   instance_ref = client.resource_parser.Parse(
       args.instance,
       params={'project': properties.VALUES.core.project.GetOrFail},
@@ -345,7 +343,7 @@ class Patch(base.UpdateCommand):
   """Updates the settings of a Cloud SQL instance."""
 
   def Run(self, args):
-    return RunBasePatchCommand(args, self.ReleaseTrack(), False)
+    return RunBasePatchCommand(args, self.ReleaseTrack())
 
   @staticmethod
   def Args(parser):
@@ -362,7 +360,7 @@ class PatchBeta(base.UpdateCommand):
   """Updates the settings of a Cloud SQL instance."""
 
   def Run(self, args):
-    return RunBasePatchCommand(args, self.ReleaseTrack(), False)
+    return RunBasePatchCommand(args, self.ReleaseTrack())
 
   @staticmethod
   def Args(parser):
@@ -380,7 +378,7 @@ class PatchAlpha(base.UpdateCommand):
   """Updates the settings of a Cloud SQL instance."""
 
   def Run(self, args):
-    return RunBasePatchCommand(args, self.ReleaseTrack(), True)
+    return RunBasePatchCommand(args, self.ReleaseTrack())
 
   @staticmethod
   def Args(parser):
@@ -389,7 +387,6 @@ class PatchAlpha(base.UpdateCommand):
     flags.AddZone(
         parser,
         help_text=('Preferred Compute Engine zone (e.g. us-central1-a, '
-                   'us-central1-b, etc.). WARNING: Instance may be restarted.'),
-        enable_secondary_zone=True)
+                   'us-central1-b, etc.). WARNING: Instance may be restarted.'))
     AddBetaArgs(parser)
     AddAlphaArgs(parser)
